@@ -4,7 +4,7 @@
  *
  * Copyright (C) 2005 The GNOME Foundation
  * Copyright (C) 2006, 2007, 2008 Frederic Ruaudel and others (see AUTHORS)
- * Copyright (C) 2009 Pierre Wieser and others (see AUTHORS)
+ * Copyright (C) 2009, 2010 Pierre Wieser and others (see AUTHORS)
  *
  * This Program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -39,6 +39,7 @@
 
 #include "base-application.h"
 #include "base-window.h"
+#include "egg-sm-client.h"
 
 /* private class data
  */
@@ -49,16 +50,18 @@ struct BaseApplicationClassPrivate {
 /* private instance data
  */
 struct BaseApplicationPrivate {
-	gboolean     dispose_has_run;
-	int          argc;
-	gpointer     argv;
-	gboolean     is_gtk_initialized;
-	UniqueApp   *unique_app_handle;
-	int          exit_code;
-	gchar       *exit_message1;
-	gchar       *exit_message2;
-	BaseBuilder *builder;
-	BaseWindow  *main_window;
+	gboolean      dispose_has_run;
+	int           argc;
+	gpointer      argv;
+	GOptionEntry *options;
+	gboolean      is_gtk_initialized;
+	UniqueApp    *unique_app_handle;
+	int           exit_code;
+	gchar        *exit_message1;
+	gchar        *exit_message2;
+	BaseBuilder  *builder;
+	BaseWindow   *main_window;
+	EggSMClient  *sm_client;
 };
 
 /* instance properties
@@ -66,6 +69,7 @@ struct BaseApplicationPrivate {
 enum {
 	BASE_APPLICATION_PROP_ARGC_ID = 1,
 	BASE_APPLICATION_PROP_ARGV_ID,
+	BASE_APPLICATION_PROP_OPTIONS_ID,
 	BASE_APPLICATION_PROP_IS_GTK_INITIALIZED_ID,
 	BASE_APPLICATION_PROP_UNIQUE_APP_HANDLE_ID,
 	BASE_APPLICATION_PROP_EXIT_CODE_ID,
@@ -88,7 +92,9 @@ static void           instance_finalize( GObject *application );
 static gboolean       v_initialize( BaseApplication *application );
 static gboolean       v_initialize_i18n( BaseApplication *application );
 static gboolean       v_initialize_gtk( BaseApplication *application );
+static gboolean       v_manage_options( BaseApplication *application );
 static gboolean       v_initialize_application_name( BaseApplication *application );
+static gboolean       v_initialize_session_manager( BaseApplication *application );
 static gboolean       v_initialize_unique_app( BaseApplication *application );
 static gboolean       v_initialize_ui( BaseApplication *application );
 static gboolean       v_initialize_default_icon( BaseApplication *application );
@@ -98,7 +104,9 @@ static int            application_do_run( BaseApplication *application );
 static gboolean       application_do_initialize( BaseApplication *application );
 static gboolean       application_do_initialize_i18n( BaseApplication *application );
 static gboolean       application_do_initialize_gtk( BaseApplication *application );
+static gboolean       application_do_manage_options( BaseApplication *application );
 static gboolean       application_do_initialize_application_name( BaseApplication *application );
+static gboolean       application_do_initialize_session_manager( BaseApplication *application );
 static gboolean       application_do_initialize_unique_app( BaseApplication *application );
 static gboolean       application_do_initialize_ui( BaseApplication *application );
 static gboolean       application_do_initialize_default_icon( BaseApplication *application );
@@ -106,9 +114,12 @@ static gboolean       application_do_initialize_application( BaseApplication *ap
 
 static gboolean       check_for_unique_app( BaseApplication *application );
 /*static UniqueResponse on_unique_message_received( UniqueApp *app, UniqueCommand command, UniqueMessageData *message, guint time, gpointer user_data );*/
-static gint           display_dlg( BaseApplication *application, GtkMessageType type_message, GtkButtonsType type_buttons, const gchar *first, const gchar *second );
 
+static void           client_quit_cb( EggSMClient *client, BaseApplication *application );
+static void           client_quit_requested_cb( EggSMClient *client, BaseApplication *application );
+static gint           display_dlg( BaseApplication *application, GtkMessageType type_message, GtkButtonsType type_buttons, const gchar *first, const gchar *second );
 static void           display_error_message( BaseApplication *application );
+static gboolean       init_with_args( BaseApplication *application, int *argc, char ***argv, GOptionEntry *entries );
 static void           set_initialize_i18n_error( BaseApplication *application );
 static void           set_initialize_gtk_error( BaseApplication *application );
 static void           set_initialize_unique_app_error( BaseApplication *application );
@@ -177,16 +188,23 @@ class_init( BaseApplicationClass *klass )
 			BASE_APPLICATION_PROP_ARGC,
 			"Command-line arguments count",
 			"Command-line arguments count", 0, 65535, 0,
-			G_PARAM_STATIC_STRINGS | G_PARAM_READWRITE );
+			G_PARAM_CONSTRUCT_ONLY | G_PARAM_STATIC_STRINGS | G_PARAM_READWRITE );
 	g_object_class_install_property( object_class, BASE_APPLICATION_PROP_ARGC_ID, spec );
 
 	spec = g_param_spec_pointer(
 			BASE_APPLICATION_PROP_ARGV,
 			"Command-line arguments",
 			"A pointer to command-line arguments",
-			G_PARAM_STATIC_STRINGS | G_PARAM_READWRITE );
+			G_PARAM_CONSTRUCT_ONLY | G_PARAM_STATIC_STRINGS | G_PARAM_READWRITE );
 	g_object_class_install_property( object_class, BASE_APPLICATION_PROP_ARGV_ID, spec );
 
+	spec = g_param_spec_pointer(
+			BASE_APPLICATION_PROP_OPTIONS,
+			"Command-line options",
+			"A pointer to command-line options",
+			G_PARAM_CONSTRUCT_ONLY | G_PARAM_STATIC_STRINGS | G_PARAM_READWRITE );
+	g_object_class_install_property( object_class, BASE_APPLICATION_PROP_OPTIONS_ID, spec );
+
 	spec = g_param_spec_boolean(
 			BASE_APPLICATION_PROP_IS_GTK_INITIALIZED,
 			"Gtk+ initialization flag",
@@ -242,7 +260,9 @@ class_init( BaseApplicationClass *klass )
 	klass->initialize = application_do_initialize;
 	klass->initialize_i18n = application_do_initialize_i18n;
 	klass->initialize_gtk = application_do_initialize_gtk;
+	klass->manage_options = application_do_manage_options;
 	klass->initialize_application_name = application_do_initialize_application_name;
+	klass->initialize_session_manager = application_do_initialize_session_manager;
 	klass->initialize_unique_app = application_do_initialize_unique_app;
 	klass->initialize_ui = application_do_initialize_ui;
 	klass->initialize_default_icon = application_do_initialize_default_icon;
@@ -255,15 +275,16 @@ class_init( BaseApplicationClass *klass )
 }
 
 static void
-instance_init( GTypeInstance *instance, gpointer klass )
+instance_init( GTypeInstance *application, gpointer klass )
 {
 	static const gchar *thisfn = "base_application_instance_init";
 	BaseApplication *self;
 
-	g_debug( "%s: instance=%p, klass=%p", thisfn, ( void * ) instance, ( void * ) klass );
+	g_debug( "%s: application=%p (%s), klass=%p",
+			thisfn, ( void * ) application, G_OBJECT_TYPE_NAME( application ), ( void * ) klass );
 
-	g_return_if_fail( BASE_IS_APPLICATION( instance ));
-	self = BASE_APPLICATION( instance );
+	g_return_if_fail( BASE_IS_APPLICATION( application ));
+	self = BASE_APPLICATION( application );
 
 	self->private = g_new0( BaseApplicationPrivate, 1 );
 
@@ -290,6 +311,10 @@ instance_get_property( GObject *object, guint property_id, GValue *value, GParam
 				g_value_set_pointer( value, self->private->argv );
 				break;
 
+			case BASE_APPLICATION_PROP_OPTIONS_ID:
+				g_value_set_pointer( value, self->private->options );
+				break;
+
 			case BASE_APPLICATION_PROP_IS_GTK_INITIALIZED_ID:
 				g_value_set_boolean( value, self->private->is_gtk_initialized );
 				break;
@@ -344,6 +369,10 @@ instance_set_property( GObject *object, guint property_id, const GValue *value,
 				self->private->argv = g_value_get_pointer( value );
 				break;
 
+			case BASE_APPLICATION_PROP_OPTIONS_ID:
+				self->private->options = g_value_get_pointer( value );
+				break;
+
 			case BASE_APPLICATION_PROP_IS_GTK_INITIALIZED_ID:
 				self->private->is_gtk_initialized = g_value_get_boolean( value );
 				break;
@@ -387,7 +416,7 @@ instance_dispose( GObject *application )
 	static const gchar *thisfn = "base_application_instance_dispose";
 	BaseApplication *self;
 
-	g_debug( "%s: application=%p", thisfn, ( void * ) application );
+	g_debug( "%s: application=%p (%s)", thisfn, ( void * ) application, G_OBJECT_TYPE_NAME( application ));
 	g_return_if_fail( BASE_IS_APPLICATION( application ));
 	self = BASE_APPLICATION( application );
 
@@ -403,6 +432,10 @@ instance_dispose( GObject *application )
 			g_object_unref( self->private->builder );
 		}
 
+		if( self->private->sm_client ){
+			g_object_unref( self->private->sm_client );
+		}
+
 		/* chain up to the parent class */
 		if( G_OBJECT_CLASS( st_parent_class )->dispose ){
 			G_OBJECT_CLASS( st_parent_class )->dispose( application );
@@ -765,6 +798,19 @@ v_initialize_gtk( BaseApplication *application )
 	return( ok );
 }
 
+static gboolean
+v_manage_options( BaseApplication *application )
+{
+	static const gchar *thisfn = "base_application_v_manage_options";
+	gboolean ok;
+
+	g_debug( "%s: application=%p", thisfn, ( void * ) application );
+
+	ok = BASE_APPLICATION_GET_CLASS( application )->manage_options( application );
+
+	return( ok );
+}
+
 static gboolean
 v_initialize_application_name( BaseApplication *application )
 {
@@ -778,6 +824,19 @@ v_initialize_application_name( BaseApplication *application )
 	return( ok );
 }
 
+static gboolean
+v_initialize_session_manager( BaseApplication *application )
+{
+	static const gchar *thisfn = "base_application_v_initialize_session_manager";
+	gboolean ok;
+
+	g_debug( "%s: application=%p", thisfn, ( void * ) application );
+
+	ok = BASE_APPLICATION_GET_CLASS( application )->initialize_session_manager( application );
+
+	return( ok );
+}
+
 static gboolean
 v_initialize_unique_app( BaseApplication *application )
 {
@@ -880,8 +939,10 @@ application_do_initialize( BaseApplication *application )
 
 	return(
 			v_initialize_i18n( application ) &&
-			v_initialize_gtk( application ) &&
 			v_initialize_application_name( application ) &&
+			v_initialize_gtk( application ) &&
+			v_manage_options( application ) &&
+			v_initialize_session_manager( application ) &&
 			v_initialize_unique_app( application ) &&
 			v_initialize_ui( application ) &&
 			v_initialize_default_icon( application ) &&
@@ -913,20 +974,40 @@ application_do_initialize_gtk( BaseApplication *application )
 	int argc;
 	gpointer argv;
 	gboolean ret;
+	GOptionEntry *options;
 
 	g_debug( "%s: application=%p", thisfn, ( void * ) application );
 
-	g_object_get( G_OBJECT( application ), BASE_APPLICATION_PROP_ARGC, &argc, BASE_APPLICATION_PROP_ARGV, &argv, NULL );
+	g_object_get( G_OBJECT( application ),
+			BASE_APPLICATION_PROP_ARGC, &argc,
+			BASE_APPLICATION_PROP_ARGV, &argv,
+			BASE_APPLICATION_PROP_OPTIONS, &options,
+			NULL );
 
-	ret = gtk_init_check( &argc, ( char *** ) &argv );
+	if( options ){
+		ret = init_with_args( application, &argc, ( char *** ) &argv, options );
+	} else {
+		ret = gtk_init_check( &argc, ( char *** ) &argv );
+	}
 
 	if( ret ){
-		g_object_set( G_OBJECT( application ), BASE_APPLICATION_PROP_ARGC, argc, BASE_APPLICATION_PROP_ARGV, argv, NULL );
+		application->private->argc = argc;
+		application->private->argv = argv;
 	}
 
 	return( ret );
 }
 
+static gboolean
+application_do_manage_options( BaseApplication *application )
+{
+	static const gchar *thisfn = "base_application_do_manage_options";
+
+	g_debug( "%s: application=%p", thisfn, ( void * ) application );
+
+	return( TRUE );
+}
+
 static gboolean
 application_do_initialize_application_name( BaseApplication *application )
 {
@@ -944,6 +1025,34 @@ application_do_initialize_application_name( BaseApplication *application )
 	return( TRUE );
 }
 
+static gboolean
+application_do_initialize_session_manager( BaseApplication *application )
+{
+	static const gchar *thisfn = "base_application_do_initialize_session_manager";
+	gboolean ret = TRUE;
+
+	g_debug( "%s: application=%p", thisfn, ( void * ) application );
+
+	egg_sm_client_set_mode( EGG_SM_CLIENT_MODE_NO_RESTART );
+	application->private->sm_client = egg_sm_client_get();
+	egg_sm_client_startup();
+	g_debug( "%s: sm_client=%p", thisfn, ( void * ) application->private->sm_client );
+
+	g_signal_connect(
+			application->private->sm_client,
+	        "quit-requested",
+	        G_CALLBACK( client_quit_requested_cb ),
+	        application );
+
+	g_signal_connect(
+			application->private->sm_client,
+	        "quit",
+	        G_CALLBACK( client_quit_cb ),
+	        application );
+
+	return( ret );
+}
+
 static gboolean
 application_do_initialize_unique_app( BaseApplication *application )
 {
@@ -1076,6 +1185,34 @@ on_unique_message_received(
 	return( resp );
 }*/
 
+static void
+client_quit_cb( EggSMClient *client, BaseApplication *application )
+{
+	static const gchar *thisfn = "base_application_client_quit_cb";
+
+	g_debug( "%s: client=%p, application=%p", thisfn, ( void * ) client, ( void * ) application );
+
+	if( BASE_IS_WINDOW( application->private->main_window )){
+		g_object_unref( application->private->main_window );
+		application->private->main_window = NULL;
+	}
+}
+
+static void
+client_quit_requested_cb( EggSMClient *client, BaseApplication *application )
+{
+	static const gchar *thisfn = "base_application_client_quit_requested_cb";
+	gboolean willing_to = TRUE;
+
+	g_debug( "%s: client=%p, application=%p", thisfn, ( void * ) client, ( void * ) application );
+
+	if( BASE_IS_WINDOW( application->private->main_window )){
+		willing_to = base_window_is_willing_to_quit( application->private->main_window );
+	}
+
+	egg_sm_client_will_quit( client, willing_to );
+}
+
 static gint
 display_dlg( BaseApplication *application, GtkMessageType type_message, GtkButtonsType type_buttons, const gchar *first, const gchar *second )
 {
@@ -1123,6 +1260,29 @@ display_error_message( BaseApplication *application )
 	}
 }
 
+static gboolean
+init_with_args( BaseApplication *application, int *argc, char ***argv, GOptionEntry *entries )
+{
+	static const gchar *thisfn = "base_application_init_with_args";
+	gboolean ret;
+	char *parameter_string;
+	GError *error;
+
+	parameter_string = g_strdup( g_get_application_name());
+	error = NULL;
+
+	ret = gtk_init_with_args( argc, argv, parameter_string, entries, GETTEXT_PACKAGE, &error );
+	if( error ){
+		g_warning( "%s: %s", thisfn, error->message );
+		g_error_free( error );
+		ret = FALSE;
+	}
+
+	g_free( parameter_string );
+
+	return( ret );
+}
+
 static void
 set_initialize_i18n_error( BaseApplication *application )
 {
